embassy-stm32

Crates

git

Versions

stm32h747ig-cm7

Flavors

DataPackingMode

Enum DataPackingMode 

#[repr(u8)]
pub enum DataPackingMode { Standard = 0, Interleaved = 1, Dual = 2, }
Data packing mode in CHyDATINR register

Variants



Standard = 0

input data in DFSDM_CHyDATINR register are stored only in INDAT0[15:0]. To empty DFSDM_CHyDATINR register one sample must be read by the DFSDM filter from channel y



Interleaved = 1

Interleaved: input data in DFSDM_CHyDATINR register are stored as two samples: -first sample in INDAT0[15:0] (assigned to channel y) -second sample INDAT1[15:0] (assigned to channel y) To empty DFSDM_CHyDATINR register, two samples must be read by the digital filter from channel y (INDAT0[15:0] part is read as first sample and then INDAT1[15:0] part is read as next sample).



Dual = 2

Dual: input data in DFSDM_CHyDATINR register are stored as two samples: -first sample INDAT0[15:0] (assigned to channel y) -second sample INDAT1[15:0] (assigned to channel y+1) To empty DFSDM_CHyDATINR register first sample must be read by the digital filter from channel y and second sample must be read by another digital filter from channel y+1. Dual mode is available only on even channel numbers (y = 0, 2, 4, 6), for odd channel numbers (y = 1, 3, 5, 7) DFSDM_CHyDATINR is write protected. If an even channel is set to dual mode then the following odd channel must be set into standard mode (DATPACK[1:0]=0) for correct cooperation with even channel.